"""Repeatedly ask QUEST to add you into a particular course."""

# Expose useful imports.
from .course_adder import addcourse
from .class_numbers import numbers
from .version import (
    __author__,
    __license__,
    __copyright__,
    __version__,
)
